require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xdscwebservice',
  dscmeta_resource_friendly_name: 'xDSCWebService',
  dscmeta_resource_name: 'DSC_xDSCWebService',
  dscmeta_module_name: 'xPSDesiredStateConfiguration',
  dscmeta_module_version: '9.1.0',
  docs: %q{
    The DSC xDSCWebService resource type.
    Automatically generated from version 9.1.0
  },
  features: ['simple_get_filter'],
  attributes: {
    ensure: {
      type:    'Enum[present, absent]',
      desc:    'Whether this resource should be present or absent on the target system.',
      default: 'present',
    },
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_modulepath: {
      type: "Optional[String]",
      desc: %q{
        The location on the disk where the Modules are stored.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_registrationkeypath: {
      type: "Optional[String]",
      desc: %q{
        The location on the disk where the RegistrationKeys file is stored.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sqlprovider: {
      type: "Optional[Boolean]",
      desc: %q{
        Enable DSC Pull Server to use SQL server as the backend database.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_port: {
      type: "Optional[Integer[0, 4294967295]]",
      desc: %q{
        The port number of the DSC Pull Server IIS Endpoint.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_applicationpoolname: {
      type: "Optional[String]",
      desc: %q{
        The IIS ApplicationPool to use for the Pull Server. If not specified a pool with name 'PSWS' will be created.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_configurefirewall: {
      type: "Optional[Boolean]",
      desc: %q{
        Enable incomming firewall exceptions for the configured DSC Pull Server port. Defaults to true.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: "Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]",
      desc: %q{},
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_configurationpath: {
      type: "Optional[String]",
      desc: %q{
        The location on the disk where the Configuration is stored.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_certificatetemplatename: {
      type: "Optional[String]",
      desc: %q{
        The certificate Template Name of the Certificate in CERT:\LocalMachine\MY\ for Pull Server.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['present', 'absent']]",
      desc: %q{
        Specifies if the DSC Web Service should be installed.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sqlconnectionstring: {
      type: "Optional[String]",
      desc: %q{
        The connection string to use to connect to the SQL server backend database. Required if SqlProvider is true.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_certificatesubject: {
      type: "Optional[String]",
      desc: %q{
        The subject of the Certificate in CERT:\LocalMachine\MY\ for Pull Server.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_usesecuritybestpractices: {
      type: "Boolean",
      desc: %q{
        This property will ensure that the Pull Server is created with the most secure practices.
      },
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_physicalpath: {
      type: "Optional[String]",
      desc: %q{
        The physical path for the IIS Endpoint on the machine (usually under inetpub).
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_certificatethumbprint: {
      type: "Optional[String]",
      desc: %q{
        The thumbprint of the Certificate in CERT:\LocalMachine\MY\ for Pull Server.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_state: {
      type: "Optional[Enum['started', 'stopped']]",
      desc: %q{
        Specifies the state of the DSC Web Service.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_disablesecuritybestpractices: {
      type: "Optional[Array[Enum['securetlsprotocols']]]",
      desc: %q{
        A list of exceptions to the security best practices to apply.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_databasepath: {
      type: "Optional[String]",
      desc: %q{
        The location on the disk where the database is stored.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_endpointname: {
      type: "Optional[String]",
      desc: %q{
        Prefix of the WCF SVC file.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enable32bitapponwin64: {
      type: "Optional[Boolean]",
      desc: %q{
        Enable the DSC Pull Server to run in a 32-bit process on a 64-bit operating system.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_acceptselfsignedcertificates: {
      type: "Optional[Boolean]",
      desc: %q{
        Specifies is self-signed certs will be accepted for client authentication.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
