require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xmsipackage',
  dscmeta_resource_friendly_name: 'xMsiPackage',
  dscmeta_resource_name: 'DSC_xMsiPackage',
  dscmeta_module_name: 'xPSDesiredStateConfiguration',
  dscmeta_module_version: '9.1.0',
  docs: %q{
    The DSC xMsiPackage resource type.
    Automatically generated from version 9.1.0
  },
  features: ['simple_get_filter'],
  attributes: {
    ensure: {
      type:    'Enum[present, absent]',
      desc:    'Whether this resource should be present or absent on the target system.',
      default: 'present',
    },
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_ignorereboot: {
      type: "Optional[Boolean]",
      desc: %q{
        Ignore a pending reboot if requested by package installation.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_signerthumbprint: {
      type: "Optional[String]",
      desc: %q{
        The certificate thumbprint that should match the signer certificate of the digital signature of the MSI file.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_runascredential: {
      type: "Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]",
      desc: %q{
        The credential of a user account under which to run the installation or uninstallation of the MSI package.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_psdscrunascredential: {
      type: "Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]",
      desc: %q{},
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_credential: {
      type: "Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]",
      desc: %q{
        The credential of a user account to be used to mount a UNC path if needed.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_ensure: {
      type: "Optional[Enum['present', 'absent']]",
      desc: %q{
        Specifies whether or not the MSI file should be installed or uninstalled.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_arguments: {
      type: "Optional[String]",
      desc: %q{
        The arguments to be passed to the MSI package during installation or uninstallation.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_hashalgorithm: {
      type: "Optional[Enum['sha1', 'sha256', 'sha384', 'sha512', 'md5', 'ripemd160']]",
      desc: %q{
        The algorithm used to generate the given hash value.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_filehash: {
      type: "Optional[String]",
      desc: %q{
        The expected hash value of the MSI file at the given path.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_servercertificatevalidationcallback: {
      type: "Optional[String]",
      desc: %q{
        PowerShell code that should be used to validate SSL certificates for paths using HTTPS.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_path: {
      type: "String",
      desc: %q{
        The path to the MSI file that should be installed or uninstalled.
      },
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_productid: {
      type: "Optional[String]",
      desc: %q{
        The identifying number used to find the package, usually a GUID.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_signersubject: {
      type: "Optional[String]",
      desc: %q{
        The subject that should match the signer certificate of the digital signature of the MSI file.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_logpath: {
      type: "Optional[String]",
      desc: %q{
        The path to the log file to log the output from the MSI execution.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
