require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xpsendpoint',
  dscmeta_resource_friendly_name: 'xPSEndpoint',
  dscmeta_resource_name: 'DSC_xPSSessionConfiguration',
  dscmeta_module_name: 'xPSDesiredStateConfiguration',
  dscmeta_module_version: '9.1.0',
  docs: %q{
    The DSC xPSEndpoint resource type.
    Automatically generated from version 9.1.0
  },
  features: ['simple_get_filter'],
  attributes: {
    ensure: {
      type:    'Enum[present, absent]',
      desc:    'Whether this resource should be present or absent on the target system.',
      default: 'present',
    },
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_psdscrunascredential: {
      type: "Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]",
      desc: %q{},
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_accessmode: {
      type: "Optional[Enum['local', 'remote', 'disabled']]",
      desc: %q{
        Enables and disables the session configuration and determines whether it can be used for remote or local sessions on the computer. The default value is 'Remote'.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: "Optional[String]",
      desc: %q{
        Specifies the name of the session configuration.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_securitydescriptorsddl: {
      type: "Optional[String]",
      desc: %q{
        Specifies the Security Descriptor Definition Language (SDDL) string for the configuration.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['present', 'absent']]",
      desc: %q{
        Indicates if the session configuration should exist. The default value is 'Present'.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_startupscript: {
      type: "Optional[String]",
      desc: %q{
        Specifies the startup script for the configuration. Enter the fully qualified path of a Windows PowerShell script.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_runascredential: {
      type: "Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]",
      desc: %q{
        Specifies the credential for commands of this session configuration.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
  },
)
