require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xremotefile',
  dscmeta_resource_friendly_name: 'xRemoteFile',
  dscmeta_resource_name: 'DSC_xRemoteFile',
  dscmeta_module_name: 'xPSDesiredStateConfiguration',
  dscmeta_module_version: '9.1.0',
  docs: %q{
    The DSC xRemoteFile resource type.
    Automatically generated from version 9.1.0
  },
  features: ['simple_get_filter'],
  attributes: {
    ensure: {
      type:    'Enum[present, absent]',
      desc:    'Whether this resource should be present or absent on the target system.',
      default: 'present',
    },
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_proxycredential: {
      type: "Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]",
      desc: %q{
        Specifies a user account that has permission to use the proxy server that is specified by the Proxy parameter.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_useragent: {
      type: "Optional[String]",
      desc: %q{
        User agent for the web request.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: "Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]",
      desc: %q{},
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_timeoutsec: {
      type: "Optional[Integer[0, 4294967295]]",
      desc: %q{
        Specifies how long the request can be pending before it times out.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_checksum: {
      type: "Optional[String]",
      desc: %q{
        Specifies the checksum value to compare against the downloaded file
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_matchsource: {
      type: "Optional[Boolean]",
      desc: %q{
        A boolean value to indicate whether the remote file should be re-downloaded if the file in the DestinationPath was modified locally. The default value is true.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_headers: {
      type: "Array[Struct[{
              key => Optional[String],
              value => Optional[String],
            }]]",
      desc: %q{
        Headers of the web request.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_KeyValuePair[]',
      mof_is_embedded: true,
    },
    dsc_destinationpath: {
      type: "Optional[String]",
      desc: %q{
        Path under which downloaded or copied file should be accessible after operation.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_checksumtype: {
      type: "Optional[Enum['none', 'sha1', 'sha256', 'sha384', 'sha512', 'mactripledes', 'md5', 'ripemd160']]",
      desc: %q{
        Specifies the checksum type to verify the downloaded file
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_credential: {
      type: "Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]",
      desc: %q{
        Specifies a user account that has permission to send the request.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_uri: {
      type: "String",
      desc: %q{
        Uri of a file which should be copied or downloaded. This parameter supports HTTP and HTTPS values.
      },
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_proxy: {
      type: "Optional[String]",
      desc: %q{
        Uses a proxy server for the request, rather than connecting directly to the Internet resource. Should be the URI of a network proxy server (e.g 'http://10.20.30.1').
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
