require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xscript',
  dscmeta_resource_friendly_name: 'xScript',
  dscmeta_resource_name: 'DSC_xScriptResource',
  dscmeta_module_name: 'xPSDesiredStateConfiguration',
  dscmeta_module_version: '9.1.0',
  docs: %q{
    The DSC xScript resource type.
    Automatically generated from version 9.1.0
  },
  features: ['simple_get_filter'],
  attributes: {
    ensure: {
      type:    'Enum[present, absent]',
      desc:    'Whether this resource should be present or absent on the target system.',
      default: 'present',
    },
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_credential: {
      type: "Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]",
      desc: %q{
        The credential of the user account to run the script under if needed.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_setscript: {
      type: "Optional[String]",
      desc: %q{
        A string that can be used to create a PowerShell script block that sets the resource to the desired state.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_getscript: {
      type: "Optional[String]",
      desc: %q{
        A string that can be used to create a PowerShell script block that retrieves the current state of the resource.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: "Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]",
      desc: %q{},
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_testscript: {
      type: "Optional[String]",
      desc: %q{
        A string that can be used to create a PowerShell script block that validates whether or not the resource is in the desired state.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
