require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xservice',
  dscmeta_resource_friendly_name: 'xService',
  dscmeta_resource_name: 'DSC_xServiceResource',
  dscmeta_module_name: 'xPSDesiredStateConfiguration',
  dscmeta_module_version: '9.1.0',
  docs: %q{
    The DSC xService resource type.
    Automatically generated from version 9.1.0
  },
  features: ['simple_get_filter'],
  attributes: {
    ensure: {
      type:    'Enum[present, absent]',
      desc:    'Whether this resource should be present or absent on the target system.',
      default: 'present',
    },
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_description: {
      type: "Optional[String]",
      desc: %q{
        The description of the service.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_terminatetimeout: {
      type: "Optional[Integer[0, 4294967295]]",
      desc: %q{
        The time to wait for the service to stop in milliseconds. Defaults to 30000.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_displayname: {
      type: "Optional[String]",
      desc: %q{
        The display name of the service.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_startuptimeout: {
      type: "Optional[Integer[0, 4294967295]]",
      desc: %q{
        The time to wait for the service to start in milliseconds. Defaults to 30000.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_groupmanagedserviceaccount: {
      type: "Optional[String]",
      desc: %q{
        The Group Managed Service Account to run the service under.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: "Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]",
      desc: %q{},
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_name: {
      type: "Optional[String]",
      desc: %q{
        Indicates the service name. Note that sometimes this is different from the display name. You can get a list of the services and their current state with the Get-Service cmdlet.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_credential: {
      type: "Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]",
      desc: %q{
        The credential to run the service under.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_ensure: {
      type: "Optional[Enum['present', 'absent']]",
      desc: %q{
        Ensures that the service is present or absent. Defaults to Present.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_builtinaccount: {
      type: "Optional[Enum['localsystem', 'localservice', 'networkservice']]",
      desc: %q{
        Indicates the sign-in account to use for the service.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_startuptype: {
      type: "Optional[Enum['automatic', 'manual', 'disabled']]",
      desc: %q{
        Indicates the startup type for the service.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_state: {
      type: "Optional[Enum['running', 'stopped', 'ignore']]",
      desc: %q{
        Indicates the state you want to ensure for the service. Defaults to Running.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_desktopinteract: {
      type: "Optional[Boolean]",
      desc: %q{
        The service can create or communicate with a window on the desktop. Must be false for services not running as LocalSystem. Defaults to False.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_path: {
      type: "Optional[String]",
      desc: %q{
        The path to the service executable file.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_dependencies: {
      type: "Optional[Array[String]]",
      desc: %q{
        An array of strings indicating the names of the dependencies of the service.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
  },
)
