require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xwindowsoptionalfeature',
  dscmeta_resource_friendly_name: 'xWindowsOptionalFeature',
  dscmeta_resource_name: 'DSC_xWindowsOptionalFeature',
  dscmeta_module_name: 'xPSDesiredStateConfiguration',
  dscmeta_module_version: '9.1.0',
  docs: %q{
    The DSC xWindowsOptionalFeature resource type.
    Automatically generated from version 9.1.0
  },
  features: ['simple_get_filter'],
  attributes: {
    ensure: {
      type:    'Enum[present, absent]',
      desc:    'Whether this resource should be present or absent on the target system.',
      default: 'present',
    },
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_removefilesondisable: {
      type: "Optional[Boolean]",
      desc: %q{
        Specifies that all files associated with the feature should be removed if the feature is being disabled.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: "Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]",
      desc: %q{},
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_ensure: {
      type: "Optional[Enum['present', 'absent']]",
      desc: %q{
        Specifies whether the feature should be enabled or disabled. To enable the feature, set this property to Present. To disable the feature, set the property to Absent.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_logpath: {
      type: "Optional[String]",
      desc: %q{
        The path to the log file to log this operation.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_nowindowsupdatecheck: {
      type: "Optional[Boolean]",
      desc: %q{
        Specifies whether or not DISM contacts Windows Update (WU) when searching for the source files to enable the feature. If $true, DISM will not contact WU.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: "Optional[String]",
      desc: %q{
        The name of the feature to enable or disable.
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_loglevel: {
      type: "Optional[Enum['errorsonly', 'errorsandwarning', 'errorsandwarningandinformation']]",
      desc: %q{
        The maximum output level to show in the log. Accepted values are: ErrorsOnly (only errors are logged), ErrorsAndWarning (errors and warnings are logged), and ErrorsAndWarningAndInformation (errors, warnings, and debug information are logged).
      },
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
